@@ -38,7 +38,13 @@ def get_conf(conf):
         raise
 
 
+def dummy_task_error_handler(task_id, exception): pass
+
+
 default_settings = {
+    'task': {
+        'error_handler': dummy_task_error_handler
+    },
     'views': {
         'paginate': 20,
         'security_raise_exception': True,
@@ -87,6 +93,7 @@ default_settings = {
             'create': {
                 'success_url': 'process-tasks',
                 'success_message': _('task created successfully'),
+                'redirect_to_edit': True,
                 'permissions': ['process.view_tasks', 'process.add_tasks'],
             },
             'list': {
